@@ -5,8 +5,8 @@
 ;; Author: Jonas Meurer
 ;; Keywords: text, wp, org, typst
 ;; URL: https://github.com/jmpunkt/ox-typst
-;; Package-Version: 20250926.1502
-;; Package-Revision: cc7e9665d4ea
+;; Package-Version: 20251112.1800
+;; Package-Revision: d75218627ca8
 ;; Package-Requires: ((emacs "30.1") (org "9.7"))
 
 ;; This file is not part of GNU Emacs.
@@ -575,6 +575,7 @@ will result in `ox-typst' to apply the colors to the code block."
         (email (when (plist-get info :with-email)
                  (plist-get info :email)))
         (toc (plist-get info :with-toc))
+        (date (plist-get info :date))
         (typst-header (plist-get info :typst-header)))
     (concat
      (format "#let _ = ```typ
@@ -584,6 +585,7 @@ exec %s
        (concat
         "#set document("
         (format "title: \"%s\"" (or (car title) ""))
+        (when date (format ", date: %s" (string-trim-right (string-trim-left (org-typst-timestamp (car date) contents info) "#") ".display()")))
         (when author
           (or (when email
                 (format ", author: \"<%s> %s\"" (car author) email))
@@ -1204,13 +1206,12 @@ Return PDF file name or raise an error if it couldn't be produced."
     outfile))
 
 ;; Citation Exporter
-(defun org-typst-export-bibliography (_keys files style properties _backend com)
-  (let ((dir (file-name-parent-directory (plist-get com :input-file)))
-        (title (plist-get properties :title)))
+(defun org-typst-export-bibliography (_keys files style properties _backend _com)
+  (let ((title (plist-get properties :title)))
     (format "#bibliography(%s%s(%s))"
             (and style (format "style: \"%s\", " style))
             (if title (format "title: %s, " (org-typst--as-string title)) "")
-            (mapconcat (lambda (f) (org-typst--as-string (file-relative-name f dir)))
+            (mapconcat (lambda (f) (org-typst--as-typst-path f))
                        files
                        ", "))))
 
